@@ -108,7 +108,7 @@ RcppExport SEXP frailty_GRF_LDTFP(SEXP nburn_, SEXP nsave_, SEXP nskip_, SEXP nd
   double rej;
   //double phi_min = std::pow(-log(0.001), 1.0/nu)/Dmm.max();
   double phi_min = ESMALL;
-  double sill=0.9999;
+  double sill=1.0-ESMALL;
   arma::mat Im = arma::eye(m,m);
   arma::mat Rmm=arma::zeros<arma::mat>(m,m);
   for(int i=0; i<m; ++i){
